@@ -4,7 +4,9 @@ from lhc.binf.genomic_coordinate import GenomicInterval
 
 def iter_bed(lines: Iterable[str]) -> Iterator[GenomicInterval]:
     for line in lines:
-        if line.startswith('#'):
+        if not line:
+            continue
+        elif line.startswith('#'):
             continue
         parts = line.rstrip('\r\n').split('\t')
         name = parts[3] if len(parts) > 3 else ''
@@ -17,7 +19,7 @@ def iter_bed(lines: Iterable[str]) -> Iterator[GenomicInterval]:
 
 
 def format_bed(interval: GenomicInterval) -> str:
-    return '{chr}\t{start}\t{stop}\t{data[gene_id]}\t{data[score]}\t{strand}\n'.format(
+    return '{chr}\t{start}\t{stop}\t{data[gene_id]}\t{data[score]}\t{strand}'.format(
         chr=interval.chromosome,
         start=interval.start.position + 1,
         stop=interval.stop.position,
